import numpy as np


def psth(spikes, **kwargs):

    # expects "spikes" to be a dataframe with spike times as the index, and gids as data
    trange = [kwargs['t_start'], kwargs['t_end']]
    dt = kwargs.get("dt", None)
    duration = trange[1] - trange[0]
    if dt is None:
        dt = 30.0 * float(duration) / len(spikes)
        dt = min(dt, 50.0)  # keep dt<=50.0 ms
        n_bins = int(round(duration / dt))
    else:
        n_bins = int(round(duration / dt))
    counts, bins = np.histogram(spikes.index, bins=n_bins, range=trange)
    db = bins[1] - bins[0]
    c = counts.astype(float) / len(np.unique(spikes)) / db * 1000.0  # factor of 1000 since Hz is in seconds, but time is specified in ms
    c_raw = counts.astype(float) / db * 1000.0

    return dt, c, c_raw, db, bins


def raster(sp, ys, columnHeight=2081, **kwargs):

    # normalize y heights
    y = [min(y, columnHeight) for y in ys]
    y = np.array(y)

    t_start = kwargs.get('t_start', 2400)
    t_end = kwargs.get('t_end', 3200)

    spike_times = []
    depths = []

    for i, gid in enumerate(ys.index):
        times = sp[sp==gid]
        if len(times) > 150:  # this is problomatic for long simulation and for neurons with high firing rate
            print("Stuck cell?: %d" % gid)
            continue

        if len(times) > 0:
            times = times[t_start:t_end]
            spike_times.extend(times.index)
            depths.extend([y[i]] * len(times))

    return spike_times, np.array(depths)

